==> qtjambi-uic-6.4.2-sources.jar: io/qt/uic/Option.java <==
/****************************************************************************
**
** Copyright (C) 2009-2022 Dr. Peter Droste, Omix Visualization GmbH & Co. KG. All rights reserved.
**
** This file is part of Qt Jambi.
**
** $BEGIN_LICENSE$
** GNU Lesser General Public License Usage
** This file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
** 
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
** $END_LICENSE$

**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/
package io.qt.uic;

import io.qt.core.QDir;

public class Option {
	public boolean copyrightHeader = true;
	public boolean generateImplemetation;
	public boolean generateNamespace = true;
	public boolean autoConnection = true;
	public boolean dependencies;
	public boolean limitXPM_LineLength;
	public boolean idBased;
	public boolean forceMemberFnPtrConnectionSyntax;
	public boolean forceStringConnectionSyntax;
	public boolean forceOutput;
	public String inputFile = "";
	public String outputDir = "";
	public String targetPackage = "";
	public String qrcOutputFile = "";
	public String indent = "    ";
	public String prefix = "UI_";
	public String postfix = "";
	public String translateFunction = "";
	public String imports = "";
	
	public String messagePrefix()
	{
	    return inputFile==null || inputFile.isEmpty() ? "stdin" : QDir.toNativeSeparators(inputFile);
	}
}

==> qtjambi-uic-6.4.3-sources.jar: io/qt/uic/Option.java <==
/****************************************************************************
**
** Copyright (C) 2009-2023 Dr. Peter Droste, Omix Visualization GmbH & Co. KG. All rights reserved.
**
** This file is part of Qt Jambi.
**
** $BEGIN_LICENSE$
** GNU Lesser General Public License Usage
** This file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
** 
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
** $END_LICENSE$

**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/
package io.qt.uic;

import io.qt.core.QDir;

public class Option {
	public boolean copyrightHeader = true;
	public boolean generateImplemetation;
	public boolean generateNamespace = true;
	public boolean autoConnection = true;
	public boolean dependencies;
	public boolean limitXPM_LineLength;
	public boolean idBased;
	public boolean forceMemberFnPtrConnectionSyntax;
	public boolean forceStringConnectionSyntax;
	public boolean forceOutput;
	public String inputFile = "";
	public String outputDir = "";
	public String targetPackage = "";
	public String qrcOutputFile = "";
	public String indent = "    ";
	public String prefix = "Ui_";
	public String postfix = "";
	public String translateFunction = "";
	public String imports = "";
	
	public String messagePrefix()
	{
	    return inputFile==null || inputFile.isEmpty() ? "stdin" : QDir.toNativeSeparators(inputFile);
	}
}
